import React from 'react';
import { message } from 'antd';
import { ModalForm, ProFormText } from '@ant-design/pro-components';
import type { UserAddParams } from '../../data';
import { addUser } from '../../service';

const handleAdd = async (fields: UserAddParams) => {
  const hide = message.loading('正在添加');
  try {
    const { code, msg } = await addUser({ ...fields });
    if (code === 1) {
      hide();
      message.success(msg);
      return true;
    }
    message.error(msg);
    return false;
  } catch (error) {
    hide();
    message.error('Adding failed, please try again!');
    return false;
  }
};

type AddUserViewProps = {
  state: boolean;
  onChange: (visible: boolean) => void;
  onSubmit: () => void;
};

const AddUser: React.FC<AddUserViewProps> = (props) => {
  const { state, onChange, onSubmit } = props;

  return (
    <ModalForm
      isKeyPressSubmit={false}
      title={'新建运营账户'}
      width="400px"
      visible={state}
      onVisibleChange={onChange}
      onFinish={async (value) => {
        console.log('value', value);
        const success = await handleAdd(value as UserAddParams);
        if (success) {
          onChange(false);
          onSubmit();
        }
      }}
    >
      <ProFormText
        label="账号"
        name="account"
        rules={[
          {
            required: true,
            message: '账号为必填项',
          },
        ]}
      />
      <ProFormText.Password
        label="密码"
        name="password"
        rules={[
          {
            required: true,
            message: '密码为必填项',
          },
        ]}
      />
      <ProFormText
        label="姓名"
        name="name"
        rules={[
          {
            required: true,
            message: '姓名为必填项',
          },
        ]}
      />
    </ModalForm>
  );
};
export default AddUser;
