import { request } from 'umi';
import type {
  CurrentUser,
  UserAddParams,
  UserDisableSwitchParams,
  UserEditParams,
  UserIdentityParams,
  UserResult,
} from './data';

export async function addUser(body: UserAddParams, options?: Record<string, any>) {
  return request<API.Result<UserResult>>('/api/user', {
    method: 'POST',
    data: body,
    ...(options || {}),
  });
}

export async function editUser(
  user_id: number,
  body: UserEditParams,
  options?: Record<string, any>,
) {
  return request<API.Result<UserResult>>(`/api/user/${user_id}`, {
    method: 'PUT',
    data: body,
    ...(options || {}),
  });
}

export async function identityUser(
  user_id: number,
  body: UserIdentityParams,
  options?: Record<string, any>,
) {
  return request<API.Result<UserResult>>(`/api/user/${user_id}/identity`, {
    method: 'PATCH',
    data: body,
    ...(options || {}),
  });
}

export async function disableSwitchUser(
  user_id: number,
  body: UserDisableSwitchParams,
  options?: Record<string, any>,
) {
  return request<API.Result<UserResult>>(`/api/user/${user_id}/disable`, {
    method: 'PATCH',
    data: body,
    ...(options || {}),
  });
}

export async function findUser(user_id: number, options?: Record<string, any>) {
  return request<API.Result<UserResult>>(`/api/user/${user_id}`, {
    method: 'GET',
    ...(options || {}),
  });
}

export async function currentUser(options?: Record<string, any>) {
  return request<API.Result<CurrentUser>>('/api/currentUser', {
    method: 'GET',
    ...(options || {}),
  });
}

export async function userList(
  params: { current?: number; pageSize?: number; [key: string]: any },
  options?: Record<string, any>,
) {
  const { current, pageSize } = params;
  delete params.current;
  delete params.pageSize;
  return request<API.Result<API.Page<UserResult>>>('/api/user', {
    method: 'GET',
    params: {
      ...params,
      page: current,
      limit: pageSize,
    },
    ...(options || {}),
  });
}
