import React, { useEffect, useState } from 'react';
import { Card, Form, message, Spin } from 'antd';
import { ProForm, ProFormText } from '@ant-design/pro-components';
import type { UserEditParams } from '../../data';
import { editUser, findUser } from '../../service';

const handleEdit = async (user_id: number, fields: UserEditParams) => {
  const hide = message.loading('正在修改');
  try {
    const { code, msg } = await editUser(user_id, { ...fields });
    if (code === 1) {
      hide();
      message.success(msg);
      return true;
    }
    message.error(msg);
    return false;
  } catch (error) {
    hide();
    message.error('Adding failed, please try again!');
    return false;
  }
};

type EditUserViewProps = {
  title: string;
  user_id: number;
};

const EditUser: React.FC<EditUserViewProps> = (props) => {
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(true);

  const { title, user_id } = props;

  const handleRefresh = () => {
    setLoading(true);
    findUser(user_id).then(({ code, data }) => {
      if (code === 1) {
        form.setFieldsValue(data);
        setLoading(false);
      }
    });
  };

  useEffect(() => {
    findUser(user_id).then(({ code, data }) => {
      if (code === 1) {
        form.setFieldsValue(data);
        setLoading(false);
      }
    });
  }, [form, user_id]);

  return (
    <Spin spinning={loading}>
      <Card>
        <ProForm
          form={form}
          isKeyPressSubmit={false}
          title={title}
          onFinish={async (value) => {
            setLoading(true);
            const success = await handleEdit(user_id, value);
            if (success) {
            }
            setLoading(false);
          }}
          onReset={() => {
            handleRefresh();
          }}
        >
          <ProFormText
            label="账号"
            name="account"
            rules={[
              {
                required: true,
                message: '账号为必填项',
              },
            ]}
          />
          <ProFormText.Password label="密码" name="password" />
          <ProFormText
            label="姓名"
            name="name"
            rules={[
              {
                required: true,
                message: '姓名为必填项',
              },
            ]}
          />
        </ProForm>
      </Card>
    </Spin>
  );
};
export default EditUser;
